AuthAccountUnlinked class

Result of unlinking a provider account.

Constructors

AuthAccountUnlinked({required String providerId, required String providerAccountId, required DateTime unlinkedAt})
Creates an instance of AuthAccountUnlinked.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
providerAccountId String
Provider-specific account ID.
final
providerId String
Provider identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unlinkedAt DateTime
When the account was unlinked.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited