AuthAdminPrepareStopImpersonatingMutation class final

Mutation describing auth admin prepare stop impersonating mutation.

Inheritance

Constructors

AuthAdminPrepareStopImpersonatingMutation({required String currentUserId, required String currentSessionId})
Creates an instance of AuthAdminPrepareStopImpersonatingMutation.
const

Properties

authorization AuthAdminMutationAuthorization?
The authorization associated with this value.
finalinherited
currentSessionId String
The identifier of current session.
final
currentUserId String
The identifier of current user.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited