AuthAdminSession class final

Authentication data for auth admin session.

Constructors

AuthAdminSession({required String id, required String userId, required DateTime createdAt, required DateTime expiresAt, required DateTime lastUsedAt, required String authenticationMethod, required bool active, DateTime? revokedAt, String? ipAddress, String? userAgent, String? impersonatedBy})
Creates an instance of AuthAdminSession.
const
AuthAdminSession.fromJson(Map<String, dynamic> json)
Creates an instance from a JSON map.
factory
AuthAdminSession.fromRecord(AuthSessionRecord record)
Creates an instance from a persisted record.
factory

Properties

active bool
The active associated with this value.
final
authenticationMethod String
The authentication method associated with this value.
final
createdAt DateTime
The time at which created occurred.
final
expiresAt DateTime
The time at which expires occurred.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier.
final
impersonatedBy String?
The impersonated by associated with this value.
final
ipAddress String?
The ip address associated with this value.
final
lastUsedAt DateTime
The time of the last used.
final
revokedAt DateTime?
The time at which revoked occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String?
The user agent associated with this value.
final
userId String
The identifier of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited