AuthAdminSetAccountStateMutation class final

Mutation describing auth admin set account state mutation.

Inheritance

Constructors

AuthAdminSetAccountStateMutation({required AuthAdminMutationAuthorization? authorization, required String userId, required AuthAdminAccountStateAction action, String? reason})
Creates an instance of AuthAdminSetAccountStateMutation.
const

Properties

action AuthAdminAccountStateAction
The action associated with this value.
final
authorization AuthAdminMutationAuthorization?
The authorization associated with this value.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
reason String?
The reason associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
The identifier of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited