AuthAdminUpdateUserMutation class final

Mutation describing auth admin update user mutation.

Inheritance

Constructors

AuthAdminUpdateUserMutation({required AuthAdminMutationAuthorization? authorization, required AuthUser expectedUser, required AuthUser user, required bool revokeAccess})
Creates an instance of AuthAdminUpdateUserMutation.
const

Properties

authorization AuthAdminMutationAuthorization?
The authorization associated with this value.
finalinherited
expectedUser AuthUser
The expected user associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
revokeAccess bool
The revoke access associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
The user associated with this value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited