AuthAnonymousDeleteAccountCommand class final
Deletes an authenticated anonymous identity and all user-owned auth data.
Constructors
- AuthAnonymousDeleteAccountCommand({required String operationId, required String userId})
- Creates an instance of AuthAnonymousDeleteAccountCommand.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operationId → String
-
The identifier of operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
The identifier of the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited