AuthAuthenticationLifecycleEventType enum

Lifecycle phase emitted by the host after it completes an authentication transition or clears one.

Inheritance
  • Object
  • Enum
  • AuthAuthenticationLifecycleEventType
Available extensions

Values

authenticationSucceeded → const AuthAuthenticationLifecycleEventType

A user successfully authenticated.

signedOut → const AuthAuthenticationLifecycleEventType

The current user signed out.

accountDeleted → const AuthAuthenticationLifecycleEventType

The current account was deleted.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthAuthenticationLifecycleEventType>
A constant List of the values in this enum, in order of their declaration.