AuthCaptchaVerificationResult class final

Typed result returned by an application-owned captcha verifier.

Constructors

AuthCaptchaVerificationResult({required bool accepted})
Creates a result with the explicit accepted decision.
const
AuthCaptchaVerificationResult.accepted()
Creates an accepted verification result.
const
AuthCaptchaVerificationResult.rejected()
Creates a rejected verification result.
const

Properties

accepted bool
Whether the captcha provider accepted the token.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited