AuthClientTwoFactorEnrollment class

TOTP enrollment data returned by a two-factor plugin.

Constructors

AuthClientTwoFactorEnrollment({required String secret, required Uri otpauthUri, required DateTime expiresAt})
Creates TOTP enrollment data.
const
AuthClientTwoFactorEnrollment.fromJson(Map<String, dynamic> json)
Decodes TOTP enrollment data from JSON.
factory

Properties

expiresAt DateTime
Time at which this enrollment expires.
final
hashCode int
The hash code for this object.
no setterinherited
otpauthUri Uri
otpauth URI for authenticator applications.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
Shared secret used to generate TOTP codes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited