AuthClientWebAuthnAuthenticationResult class final

Result returned after a passkey assertion is verified.

Constructors

AuthClientWebAuthnAuthenticationResult({required AuthUser user, required AuthClientWebAuthnCredential credential, required AuthSession session})
Creates the result of a verified passkey assertion.
const
AuthClientWebAuthnAuthenticationResult.fromJson(Map<String, dynamic> json)
Decodes a passkey-authentication response from JSON.
factory

Properties

credential AuthClientWebAuthnCredential
Passkey metadata updated by the verification.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session AuthSession
Session issued after the assertion was verified.
final
user AuthUser
User authenticated by the passkey.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited