AuthEmailBackendInjectedFault class final

Exception raised when a configured email-transaction fault is triggered.

Implemented types

Constructors

AuthEmailBackendInjectedFault(AuthEmailBackendFaultPoint point)
Creates a test fault associated with point.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
point AuthEmailBackendFaultPoint
Transaction location at which the fault was injected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited