AuthFieldDescriptor class final

Describes one persisted field in an auth plugin schema.

Constructors

AuthFieldDescriptor({required String name, required String kind})
Creates a field descriptor with its name and storage kind.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
Storage or schema kind for the field.
final
name String
Field name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited