AuthGateRegistry<TContext> class

Registry for gate callbacks keyed by ability.

Constructors

AuthGateRegistry()

Properties

abilities Iterable<String>
All registered ability names.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String ability, AuthGateCallback<TContext> callback, {bool overrideExisting = true}) → void
Registers a gate callback for ability.
registerAll(Map<String, AuthGateCallback<TContext>> entries, {bool overrideExisting = true}) → void
Registers multiple gate callbacks.
resolve(String ability) AuthGateCallback<TContext>?
Resolves callback for ability.
toString() String
A string representation of this object.
inherited
unregister(String ability) → void
Unregisters ability.

Operators

operator ==(Object other) bool
The equality operator.
inherited