AuthInMemoryStoreDeletionOperation class final
Adapts one typed in-memory store into an immutable plan operation.
- Implemented types
Constructors
- AuthInMemoryStoreDeletionOperation({required AuthInMemoryUserDeletionStore store, required String userId})
- Creates an instance of AuthInMemoryStoreDeletionOperation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
) → FutureOr< void> -
Applies the requested value.
override
-
captureState(
) → Object -
Captures state.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreState(
Object state) → FutureOr< void> -
Restores state.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited