AuthLastAuthenticationMethodClientPlugin class final

Installs only the typed last-authentication-method read API.

Implemented types

Constructors

AuthLastAuthenticationMethodClientPlugin()
Creates the client plugin.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used to install the matching server plugin.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install(AuthClientPluginContext context) AuthLastAuthenticationMethodClient
Installs a typed client using the transport from context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited