AuthLinkedAccountInfo class

Information about a linked provider account.

Constructors

AuthLinkedAccountInfo({required String providerId, required String providerAccountId, required DateTime linkedAt, String? email, String? name, String? image, String? displayName})
Creates an instance of AuthLinkedAccountInfo.
const

Properties

displayLabel String
Human-readable display name combining provider and identity.
no setter
displayName String?
Optional override for the display label.
final
email String?
Email from the provider (if available).
final
hashCode int
The hash code for this object.
no setterinherited
image String?
Image from the provider (if available).
final
linkedAt DateTime
When the account was linked.
final
name String?
Name from the provider (if available).
final
providerAccountId String
Provider-specific account ID.
final
providerId String
Provider identifier (e.g., 'github', 'google').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited