AuthMagicLinkConsumeStatus enum

Outcome of consuming a magic-link record.

Inheritance
Available extensions

Values

consumed → const AuthMagicLinkConsumeStatus

The link was consumed and AuthMagicLinkConsumeResult.user is available.

invalid → const AuthMagicLinkConsumeStatus

The token did not match an active record.

expired → const AuthMagicLinkConsumeStatus

The matching record had expired.

userUnavailable → const AuthMagicLinkConsumeStatus

The token was valid but the local user could not be used.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthMagicLinkConsumeStatus>
A constant List of the values in this enum, in order of their declaration.