AuthMagicLinkIssueCommand class final

Replaces every prior active magic link for one canonical email.

Constructors

AuthMagicLinkIssueCommand(AuthMagicLinkRecord record)
Creates an issuance command that replaces prior active links.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
record AuthMagicLinkRecord
Digest-only record to persist atomically.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited