AuthOAuthAuthorizationStart class
Prepared OAuth authorization start payload.
Constructors
Properties
- codeChallenge → String?
-
PKCE challenge sent to the provider, when PKCE is enabled.
final
- codeVerifier → String?
-
PKCE verifier retained by the server, when PKCE is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonce → String?
-
OIDC nonce generated for the authorization request, when applicable.
final
-
parameters
→ Map<
String, String> -
Query parameters for the provider authorization endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
State value used to bind the callback to this authorization request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited