AuthOAuthCallbackSessionValues class

OAuth callback session values loaded for a provider.

Constructors

AuthOAuthCallbackSessionValues({required String? expectedState, required String? codeVerifier, required String? nonce, required String? callbackUrl})
Creates the session values needed to validate an OAuth callback.
const

Properties

callbackUrl String?
Callback URL stored for the completed flow.
final
codeVerifier String?
PKCE verifier stored when authorization began.
final
expectedState String?
State value stored when authorization began.
final
hashCode int
The hash code for this object.
no setterinherited
nonce String?
OIDC nonce stored when authorization began.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited