AuthOAuthProtectedResourceMetadata class final

RFC 9728 protected-resource metadata for an MCP HTTP server.

Constructors

AuthOAuthProtectedResourceMetadata({required Uri resource, required List<Uri> authorizationServers, String? resourceName, Uri? resourceDocumentation, List<String> scopesSupported = const <String>[], List<String> bearerMethodsSupported = const ['header']})
Creates protected-resource metadata for an MCP resource.
const

Properties

authorizationServers List<Uri>
Authorization servers that can issue tokens for resource.
final
bearerMethodsSupported List<String>
HTTP bearer transport methods accepted by the resource.
final
hashCode int
The hash code for this object.
no setterinherited
resource Uri
Absolute URI of the protected resource.
final
resourceDocumentation Uri?
Documentation URI for the protected resource, when supplied.
final
resourceName String?
Human-readable resource name, when supplied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopesSupported List<String>
OAuth scopes understood by the protected resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this metadata using RFC 9728 field names.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited