AuthOAuthTokenEndpointHost<TContext> class abstract interface

Host for grant handlers sharing a single OAuth token endpoint.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerOAuthTokenGrant(String grantType, AuthOAuthTokenGrantHandler<TContext> handler) → void
Registers a handler for grantType.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited