AuthOAuthUserResolution class

Result of resolving an OAuth-mapped user against persisted identities.

Constructors

AuthOAuthUserResolution({required AuthUser user, required bool isNewUser, required bool userUpdated})
Creates the result of resolving an OAuth profile to a user.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isNewUser bool
Whether the provider identity created a new user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
User found or created for the provider identity.
final
userUpdated bool
Whether an existing user profile was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited