AuthOperationContract class abstract interface

Serialization contract for one side of an auth operation.

schema is JSON Schema Draft 2020-12 metadata. It is optional at runtime, but integrations such as OpenAPI can use it without depending on a framework-specific route type.

Properties

contentType String
Media type emitted or accepted by the codec.
no setter
hashCode int
The hash code for this object.
no setterinherited
required bool
Whether the value is required by the contract.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema Map<String, Object?>
JSON Schema metadata for the encoded value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited