AuthOperationMethod enum

HTTP method exposed by a portable auth plugin operation.

Inheritance
Available extensions

Values

get → const AuthOperationMethod

Reads state without changing it.

post → const AuthOperationMethod

Creates or otherwise submits a state-changing operation.

put → const AuthOperationMethod

Replaces a resource or operation state.

patch → const AuthOperationMethod

Partially updates a resource or operation state.

delete → const AuthOperationMethod

Removes a resource or operation state.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthOperationMethod>
A constant List of the values in this enum, in order of their declaration.