AuthOrganizationAtomicMutationStore class abstract interface

Required capability for organization mutations whose authorization and invariants must be checked in the same durable transaction as the write.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeOrganizationMutation<TResult>(AuthOrganizationStoreCommand<TResult> command) FutureOr<TResult>
Executes organization mutation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited