AuthOrganizationInvitation class final

Authentication data for auth organization invitation.

Constructors

AuthOrganizationInvitation({required String id, required String organizationId, required String email, required Iterable<String> roles, required String inviterId, required AuthOrganizationInvitationStatus status, required DateTime expiresAt, required DateTime createdAt, String? teamId, Map<String, dynamic>? attributes})
Creates an instance of AuthOrganizationInvitation.
AuthOrganizationInvitation.fromJson(Map<String, dynamic> json)
Creates an instance from a JSON map.
factory

Properties

attributes Map<String, dynamic>
Additional attributes associated with this value.
final
createdAt DateTime
The time at which created occurred.
final
email String
The email associated with this value.
final
expiresAt DateTime
The time at which expires occurred.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier.
final
inviterId String
The identifier of inviter.
final
organizationId String
The identifier of the organization.
final
roles List<String>
The roles assigned to this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AuthOrganizationInvitationStatus
The status associated with this value.
final
teamId String?
The identifier of the team.
final

Methods

copyWith({Iterable<String>? roles, AuthOrganizationInvitationStatus? status, DateTime? expiresAt, String? teamId}) AuthOrganizationInvitation
Creates a copy with selected fields replaced.
isPending([DateTime? now]) bool
Returns whether this value is pending.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includeActionId = true}) Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited