allowUserToCreateOrganization property
The allow user to create organization associated with this value.
Implementation
final bool allowUserToCreateOrganization;
The allow user to create organization associated with this value.
final bool allowUserToCreateOrganization;