AuthOrganizationPermissionResult class final

Result returned by auth organization permission result.

Constructors

AuthOrganizationPermissionResult({required bool allowed, required String organizationId})
Creates an instance of AuthOrganizationPermissionResult.
const

Properties

allowed bool
The allowed associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
organizationId String
The identifier of the organization.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited