AuthOrganizationTeam class final

Authentication data for auth organization team.

Constructors

AuthOrganizationTeam({required String id, required String organizationId, required String name, required DateTime createdAt, required DateTime updatedAt, Map<String, dynamic>? attributes})
Creates an instance of AuthOrganizationTeam.
AuthOrganizationTeam.fromJson(Map<String, dynamic> json)
Creates an instance from a JSON map.
factory

Properties

attributes Map<String, dynamic>
Additional attributes associated with this value.
final
createdAt DateTime
The time at which created occurred.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier.
final
name String
The name associated with this value.
final
organizationId String
The identifier of the organization.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
The time at which updated occurred.
final

Methods

copyWith({String? name, DateTime? updatedAt}) AuthOrganizationTeam
Creates a copy with selected fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited