AuthOrganizationTeamMemberMutationCommand class final

Command describing auth organization team member mutation command.

Inheritance

Constructors

AuthOrganizationTeamMemberMutationCommand({required AuthOrganizationTeamMemberMutationKind kind, required AuthOrganizationMember actorMembership, required AuthOrganizationTeam team, required AuthOrganizationTeamMember teamMember, int? memberLimit, AuthOrganizationIdempotency? idempotency, Iterable<AuthOrganizationRole> actorRoleSnapshots = const <AuthOrganizationRole>[]})
Creates an instance of AuthOrganizationTeamMemberMutationCommand.

Properties

actorMembership AuthOrganizationMember
The actor membership associated with this value.
final
actorRoleSnapshots List<AuthOrganizationRole>
The roles assigned to this value.
final
hashCode int
The hash code for this object.
no setterinherited
idempotency AuthOrganizationIdempotency?
The idempotency associated with this value.
final
kind AuthOrganizationTeamMemberMutationKind
The kind associated with this value.
final
memberLimit int?
The member limit associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
team AuthOrganizationTeam
The team associated with this value.
final
teamMember AuthOrganizationTeamMember
The team member associated with this value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited