AuthOrganizationTeamMutationCommand class final

Command describing auth organization team mutation command.

Inheritance

Constructors

AuthOrganizationTeamMutationCommand({required AuthOrganizationTeamMutationKind kind, required AuthOrganizationMember actorMembership, required AuthOrganizationTeam team, AuthOrganizationTeam? expectedTeam, int? teamLimit, bool allowLastTeam = false, AuthOrganizationIdempotency? idempotency, Iterable<AuthOrganizationRole> actorRoleSnapshots = const <AuthOrganizationRole>[]})
Creates an instance of AuthOrganizationTeamMutationCommand.

Properties

actorMembership AuthOrganizationMember
The actor membership associated with this value.
final
actorRoleSnapshots List<AuthOrganizationRole>
The roles assigned to this value.
final
allowLastTeam bool
The allow last team associated with this value.
final
expectedTeam AuthOrganizationTeam?
The expected team associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
idempotency AuthOrganizationIdempotency?
The idempotency associated with this value.
final
kind AuthOrganizationTeamMutationKind
The kind associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
team AuthOrganizationTeam
The team associated with this value.
final
teamLimit int?
The team limit associated with this value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited