AuthOrganizationTransitionInvitationCommand class final

Command describing auth organization transition invitation command.

Inheritance

Constructors

AuthOrganizationTransitionInvitationCommand({required AuthOrganizationInvitation expectedInvitation, required AuthOrganizationInvitationStatus status, required DateTime now, required String actorId, AuthOrganizationMember? actorMembership, String? actorEmail, Iterable<AuthOrganizationRole> actorRoleSnapshots = const <AuthOrganizationRole>[]})
Creates an instance of AuthOrganizationTransitionInvitationCommand.

Properties

actorEmail String?
The actor email associated with this value.
final
actorId String
The identifier of actor.
final
actorMembership AuthOrganizationMember?
The actor membership associated with this value.
final
actorRoleSnapshots List<AuthOrganizationRole>
The roles assigned to this value.
final
expectedInvitation AuthOrganizationInvitation
The expected invitation associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
now DateTime
The now associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AuthOrganizationInvitationStatus
The status associated with this value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited