AuthPasswordPolicyContributor<TContext> class abstract interface

Optional policy consulted before a new password is accepted.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enforcePasswordPolicy(AuthPasswordPolicyRequest<TContext> request) FutureOr<void>
Enforces application policy before a password is accepted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited