AuthPhoneNumberIdentity class final
A verified E.164 phone number linked to one auth user.
Constructors
- AuthPhoneNumberIdentity({required String phoneNumber, required String userId, required DateTime createdAt, required DateTime verifiedAt})
-
Creates a verified phone identity record.
const
Properties
- createdAt → DateTime
-
Time at which the identity was created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneNumber → String
-
Canonical E.164 phone number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
Identifier of the owning user.
final
- verifiedAt → DateTime
-
Time at which the phone number was verified.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toStorageJson(
) → Map< String, dynamic> - Returns the persistence representation of this identity.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited