AuthPhoneNumberSendCodeRequest class final

JSON request for sending a phone verification code.

Constructors

AuthPhoneNumberSendCodeRequest({required String phoneNumber})
Creates a phone-code request for phoneNumber.
const
AuthPhoneNumberSendCodeRequest.fromJson(Map<String, dynamic> json)
Decodes a phone-code request from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
phoneNumber String
Phone number supplied by the caller.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Encodes this request as JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited