AuthProviderClient class final

Client for discovering providers exposed by the auth server.

Constructors

AuthProviderClient(AuthClientCore _core)
Creates a provider client backed by the shared client transport.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

list() Future<List<AuthClientProvider>>
Returns the provider metadata advertised by the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited