AuthProviderClient constructor
AuthProviderClient(
- AuthClientCore _core
Creates a provider client backed by the shared client transport.
Implementation
AuthProviderClient(this._core);
Creates a provider client backed by the shared client transport.
AuthProviderClient(this._core);