AuthRateLimitAction enum

The externally reachable authentication operation being rate limited.

Inheritance
Available extensions

Values

signIn → const AuthRateLimitAction

A credentials or email sign-in attempt.

reauthentication → const AuthRateLimitAction

A password verification that refreshes a sensitive-action proof.

register → const AuthRateLimitAction

A new credentials registration attempt.

emailVerification → const AuthRateLimitAction

A request that sends an email sign-in challenge.

emailCallback → const AuthRateLimitAction

The callback that consumes an email sign-in challenge.

oauthStart → const AuthRateLimitAction

The beginning of an OAuth authorization flow.

oauthCallback → const AuthRateLimitAction

The OAuth callback that exchanges an authorization code.

customCallback → const AuthRateLimitAction

A provider-specific callback such as a Telegram login callback.

passwordResetRequest → const AuthRateLimitAction

A request to deliver a password-reset message.

passwordResetConfirm → const AuthRateLimitAction

A request to consume a password-reset token and change a password.

twoFactor → const AuthRateLimitAction

A TOTP, recovery-code, or step-up verification attempt.

emailChangeRequest → const AuthRateLimitAction

A reauthenticated request to change the current email address.

emailChangeConfirm → const AuthRateLimitAction

Consumption of an email-change confirmation token.

Removal of a linked external authentication identity.

Verification and linking of an external authentication identity.

accountDeletion → const AuthRateLimitAction

A reauthenticated self-service account deletion request.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthRateLimitAction>
A constant List of the values in this enum, in order of their declaration.