AuthRedirectCallbackContext<TContext> class

Context passed to redirect callbacks.

Constructors

AuthRedirectCallbackContext({required TContext context, required String url, required String baseUrl, AuthProvider? provider})
Creates the context supplied to a redirect callback.

Properties

baseUrl String
Application base URL used to resolve redirects.
final
context → TContext
Framework-specific callback context.
final
hashCode int
The hash code for this object.
no setterinherited
provider AuthProvider?
Provider associated with the flow, when applicable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Candidate redirect URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited