AuthResolvedSignInResult class

Result of resolving a sign-in response for a session strategy.

Constructors

AuthResolvedSignInResult({required AuthResult result, AuthIssuedJwtToken? issuedJwt})
Creates a resolved sign-in result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
issuedJwt AuthIssuedJwtToken?
JWT issuance details when the selected strategy is JWT.
final
result AuthResult
User and session result returned to the caller.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited