AuthSamlConnectionSelector class sealed

Selects one lookup key for a SAML connection.

Constructors

AuthSamlConnectionSelector.organizationSlug(String value)
Selects a connection by organization slug.
const
factory
AuthSamlConnectionSelector.providerId(String value)
Selects a connection by provider identifier.
const
factory
AuthSamlConnectionSelector.verifiedDomain(String value)
Selects a connection by verified domain.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited