AuthScimApplicationProjectionDrift class final

Describes a difference between authoritative and projected subject state.

Constructors

AuthScimApplicationProjectionDrift({required AuthScimApplicationProjectionDriftKind kind, required AuthScimApplicationProjectionSubject subject, AuthScimApplicationProjectionSnapshot? authoritative, AuthScimApplicationProjectionRecord? current})
Creates a validated difference for one projection subject.

Properties

authoritative AuthScimApplicationProjectionSnapshot?
Authoritative snapshot, when one exists.
final
current AuthScimApplicationProjectionRecord?
Current projection record, when one exists.
final
hashCode int
The hash code for this object.
no setterinherited
kind AuthScimApplicationProjectionDriftKind
Kind of difference represented by this result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject AuthScimApplicationProjectionSubject
Subject whose state differs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited