AuthScimApplicationProjectionQuery class final

Bounded query over one exact application projection scope.

Constructors

AuthScimApplicationProjectionQuery({required AuthScimApplicationProjectionScope scope, int offset = 0, int limit = 100})
Creates a bounded query for scope.

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Maximum number of records to return.
final
offset int
Zero-based result offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope AuthScimApplicationProjectionScope
Exact scope to query.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited