AuthScimBearerTokenRequest<TContext> class final

One transient bearer verification request.

Constructors

AuthScimBearerTokenRequest({required TContext context, required String token})
Creates a transient token-resolution request.
const

Properties

context → TContext
Application request context supplied to the resolver.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Raw token received from the directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited