AuthScimBearerTokenResolver<TContext> class abstract interface

Application-owned, atomic bearer-token resolution boundary.

Implementations must look up only a cryptographic digest of the token and, in one atomic operation, validate revocation, expiry, issuer/audience when applicable, and return one immutable connection identity with its exact tenant, organization, provisioning domain, credential, and scopes. Routed never persists or issues bearer credentials.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(AuthScimBearerTokenRequest<TContext> request) FutureOr<AuthScimConnectionIdentity?>
Resolves request to an immutable connection identity, if valid.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited