AuthScimConnectionCatalogQuery class final

Bounded connection query. Adapters must enforce the exact binding.

Constructors

AuthScimConnectionCatalogQuery({required AuthScimConnectionBinding binding, int limit = 100, int offset = 0})
Creates a bounded query for connections in binding.

Properties

binding AuthScimConnectionBinding
Tenant and organization binding that results must match.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Maximum number of connections to return.
final
offset int
Zero-based result offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited