AuthScimCredentialPage class final

Bounded credential catalog page.

Constructors

AuthScimCredentialPage({required List<AuthScimCredential> items, required int total, required int limit, required int offset})
Creates a bounded page of credential metadata.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<AuthScimCredential>
Credentials in this page.
final
limit int
Maximum number of items requested for this page.
final
offset int
Zero-based offset used to produce this page.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total matching credentials across all pages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes the page.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited