AuthScimGroupMember class final

One direct, stable SCIM resource reference in a Group.

value is always the SCIM resource identifier. The optional display and reference values are presentation metadata and must never be used to infer an authentication user, application role, or access grant.

Constructors

AuthScimGroupMember({required String value, required AuthScimGroupMemberType type, String? display, Uri? reference})
Creates a bounded direct resource reference.
AuthScimGroupMember.fromJson(Map<String, dynamic> json)
Decodes a bounded Group member object.
factory

Properties

display String?
Optional display label.
final
hashCode int
The hash code for this object.
no setterinherited
reference Uri?
Optional resource reference URI.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AuthScimGroupMemberType
Referenced resource type.
final
value String
Referenced SCIM resource identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this Group member object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited