AuthScimIdempotencyBinding class final

Required replay binding for an issuance transaction.

Constructors

AuthScimIdempotencyBinding({required String key, required String fingerprint})
Creates a bounded replay binding for one mutation.

Properties

fingerprint String
Digest-like fingerprint of the original mutation payload.
final
hashCode int
The hash code for this object.
no setterinherited
key String
Caller-provided key used to recognize retries.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited