AuthScimOptions class final

Bounded SCIM server settings.

Constructors

AuthScimOptions({int defaultPageSize = 100, int maximumPageSize = 200, int maximumStartIndex = 1000000, int maximumPatchOperations = 32, int maximumGroupMembers = 1000, int maximumBearerTokenLength = 4096})
Creates bounded SCIM server settings.

Properties

defaultPageSize int
Default page size used when a request omits count.
final
hashCode int
The hash code for this object.
no setterinherited
maximumBearerTokenLength int
Maximum bearer token length accepted by the endpoint.
final
maximumGroupMembers int
Maximum direct members accepted in one Group.
final
maximumPageSize int
Maximum page size accepted by list operations.
final
maximumPatchOperations int
Maximum patch operations accepted in one document.
final
maximumStartIndex int
Maximum one-based start index accepted by list operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited