AuthScimUpdateConnectionTransaction class final
Atomic connection update command.
Constructors
- AuthScimUpdateConnectionTransaction({required AuthScimConnectionBinding binding, required AuthScimManagedConnection connection, required DateTime expectedUpdatedAt})
-
Creates an optimistic-concurrency connection update command.
const
Properties
- binding → AuthScimConnectionBinding
-
Tenant and organization binding that owns the connection.
final
- connection → AuthScimManagedConnection
-
Replacement connection metadata.
final
- expectedUpdatedAt → DateTime
-
Timestamp that must still be current for the update to apply.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited