AuthServerPlugin<TContext> class abstract interface

Contract implemented by every server plugin.

Properties

dataContract AuthServerPluginDataContract
Declares data and destructive routes owned by this plugin.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable plugin identifier.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(AuthServerPluginContext<TContext> context) → void
Configures this plugin against the shared runtime context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited