Host-owned session operations available to portable plugin endpoints.
Properties
- currentSessionId → String?
-
Current server-side session identifier, when available.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → AuthSessionStrategy
-
Session strategy used by the host.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signOut(
) → FutureOr< void> - Clears the current host-owned session.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited