AuthSessionClientPlugin class final

Adds session-management operations to an AuthClient.

Implemented types

Constructors

AuthSessionClientPlugin()
Creates the session client plugin.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable registry identifier for this plugin.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install(AuthClientPluginContext context) AuthSessionClient
Installs the session client backed by context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited