AuthSessionEvent class final
Event emitted when a session payload is produced.
Constructors
-
AuthSessionEvent({required EngineContext context, required AuthSession session, required Map<
String, dynamic> payload, required AuthSessionStrategy strategy, AuthProvider? provider}) - Creates a session event with redacted and sanitized snapshots.
Properties
- context → AuthEventContext
-
Safe request metadata from the context in which the payload was produced.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
→ Map<
String, dynamic> -
The recursively sanitized payload exposed to listeners.
final
- provider → AuthProvider?
-
The optional redacted provider associated with the session.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → AuthSession
-
The redacted session represented by the payload.
final
- strategy → AuthSessionStrategy
-
The authentication strategy associated with the session.
final
- timestamp → DateTime
-
The timestamp when the event was created.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited