AuthSessionRuntimeAdapter<TContext> class abstract

Adapter used by RememberSessionAuthRuntime to read/write framework state.

Constructors

AuthSessionRuntimeAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildExpiredRememberCookie(TContext context, String cookieName) Cookie
Builds an expired remember cookie using the framework's cookie policy.
buildRememberCookie(TContext context, String cookieName, String token, DateTime expiresAt) Cookie
Builds a remember cookie using the framework's cookie policy.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPrincipalAttribute(TContext context, String attributeKey) AuthPrincipal?
Reads a cached principal attribute from context.
readSessionPrincipal(TContext context, String sessionKey) Map<String, dynamic>?
Reads the serialized principal stored in the framework session.
requestCookies(TContext context) Iterable<Cookie>
Returns cookies received with the request.
setResponseCookie(TContext context, Cookie cookie) → void
Adds cookie to the response.
toString() String
A string representation of this object.
inherited
writePrincipalAttribute(TContext context, String attributeKey, AuthPrincipal? principal) → void
Writes or clears a cached principal attribute on context.
writeSessionPrincipal(TContext context, String sessionKey, Map<String, dynamic>? principalJson) → void
Writes or clears the serialized principal in the framework session.

Operators

operator ==(Object other) bool
The equality operator.
inherited