revokeById abstract method
Atomically revokes a session by its public persistence ID when it belongs
to userId.
Implementation
FutureOr<AuthSessionRecord?> revokeById(
String userId,
String sessionId, {
DateTime? revokedAt,
});
Atomically revokes a session by its public persistence ID when it belongs
to userId.
FutureOr<AuthSessionRecord?> revokeById(
String userId,
String sessionId, {
DateTime? revokedAt,
});