AuthSignInRouteKind enum

Sign-in route branch selected for a request.

Inheritance
Available extensions

Values

oauth → const AuthSignInRouteKind

Delegates sign-in to an OAuth provider.

email → const AuthSignInRouteKind

Sends a magic-link sign-in request.

credentials → const AuthSignInRouteKind

Processes credentials sign-in.

error → const AuthSignInRouteKind

Reports a sign-in routing error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthSignInRouteKind>
A constant List of the values in this enum, in order of their declaration.