AuthTwoFactorChallengeAttempt class

Atomic result of a pending-challenge verification attempt.

Constructors

AuthTwoFactorChallengeAttempt({required bool accepted, required bool locked, required bool expired})
Creates the outcome of one atomic challenge-code attempt.
const

Properties

accepted bool
Whether the submitted code was accepted.
final
expired bool
Whether the challenge was missing or expired.
final
hashCode int
The hash code for this object.
no setterinherited
locked bool
Whether the challenge is currently locked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited