AuthTwoFactorCompleteChallengeCommand class

Atomically completes a pending TOTP challenge and optionally trusts a device.

Constructors

AuthTwoFactorCompleteChallengeCommand({required String tokenHash, required AuthTwoFactorRecord expectedFactor, required bool valid, required AuthTwoFactorAttemptPolicy policy, AuthTwoFactorTrustedDeviceRecord? trustedDevice})
Creates the command for completing a pending TOTP challenge.
const

Properties

expectedFactor AuthTwoFactorRecord
Factor record expected by the atomic verification.
final
hashCode int
The hash code for this object.
no setterinherited
policy AuthTwoFactorAttemptPolicy
Attempt and lockout policy for this command.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenHash String
Digest of the pending challenge token.
final
trustedDevice AuthTwoFactorTrustedDeviceRecord?
Trusted-device record to create after successful verification.
final
valid bool
Whether the submitted TOTP code was valid.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited