AuthTwoFactorEnrollment class

Data returned when a user starts TOTP enrollment.

Constructors

AuthTwoFactorEnrollment({required String secret, required Uri otpauthUri, required DateTime expiresAt})
Creates the client-facing enrollment details.
const

Properties

expiresAt DateTime
Time after which the enrollment must be restarted.
final
hashCode int
The hash code for this object.
no setterinherited
otpauthUri Uri
URI suitable for a QR code or authenticator import.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
Base32 secret for the authenticator application.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the enrollment details for an API response.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited