AuthTwoFactorInjectedFault class final

Exception raised when an in-memory atomic fault is injected.

Implemented types

Constructors

AuthTwoFactorInjectedFault(AuthTwoFactorAtomicFaultPoint point)
Creates a fault associated with point.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
point AuthTwoFactorAtomicFaultPoint
Atomic write boundary at which the fault was raised.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited