AuthUserCreateResult class

Result of an atomic user create-or-find operation.

Constructors

AuthUserCreateResult({required AuthUser user, required bool created})
Creates the result of an atomic user create-or-find operation.
const

Properties

created bool
Whether this call created the returned user.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
The canonical user returned by the store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited