AuthUsernameChangeResult class final

JSON response describing a username change.

Constructors

AuthUsernameChangeResult({required String username, required AuthUser user, required bool changed})
Creates the result of a username-change transaction.
const

Properties

changed bool
Whether the stored username changed.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
User projection returned by the store.
final
username String
Canonical username returned by the store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Encodes this result as JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited