AuthUsernameClientPlugin class final

Installs only the username-first API on an AuthClient.

Implemented types

Constructors

AuthUsernameClientPlugin()
Creates the username client plugin.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used to install and retrieve this plugin.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install(AuthClientPluginContext context) AuthUsernameClient
Builds the typed API exposed by this plugin.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited