AuthUsernameFaultPoint enum
Deterministic fault points exposed by the in-memory adapter for conformance.
Values
- registrationAfterUserWrite → const AuthUsernameFaultPoint
-
Fault after a registration user write.
- changeAfterCredentialWrite → const AuthUsernameFaultPoint
-
Fault after a change credential write.
- changeAfterUserWrite → const AuthUsernameFaultPoint
-
Fault after a change user write.
- removalAfterUserWrite → const AuthUsernameFaultPoint
-
Fault after a removal user write.
- removalAfterCredentialWrite → const AuthUsernameFaultPoint
-
Fault after a removal credential write.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthUsernameFaultPoint> - A constant List of the values in this enum, in order of their declaration.