AuthUsernameRemovalCommand class final

Complete input to an atomic username removal.

Constructors

AuthUsernameRemovalCommand({required String userId, required String credentialId, required AuthAuthenticationMethodInventoryLoader loadInventory})
Creates a validated atomic username-removal command.

Properties

credentialId String
Identifier of the username credential being removed.
final
hashCode int
The hash code for this object.
no setterinherited
loadInventory AuthAuthenticationMethodInventoryLoader
Loads the complete composed topology inside the backend-owned command.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
Identifier of the user removing the username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited