AuthVerificationToken class

Verification token for email sign-in.

Constructors

AuthVerificationToken({required String identifier, required String token, required DateTime expiresAt, Map<String, dynamic>? metadata})
Creates an email verification token record.

Properties

expiresAt DateTime
Expiration timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
Identifier for the verification target (email).
final
metadata Map<String, dynamic>
Server-side data associated with the token. Implementations must persist this data with the token and must never expose the raw token in it.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Token value sent to the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited