AuthWebAuthnStoreCapabilities class abstract interface

Optional persistence capability required by the WebAuthn plugin.

Keeping these stores outside the base auth store lets existing adapters continue to implement core authentication without opting into passkeys.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webAuthnAuthenticators AuthWebAuthnAuthenticatorStore
Authenticator store owned by the capability provider.
no setter
webAuthnChallenges AuthWebAuthnChallengeStore
Challenge store owned by the capability provider.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited