FidoMetadataAttestationPathVerificationInput class final

Input to an optional verifier for an attestation path whose metadata root is omitted from the client-supplied WebAuthn certificate path.

Properties

attestation WebAuthnAttestationMetadata
Attestation whose certificate path requires application verification.
final
entry FidoMetadataEntry
Metadata entry whose roots should be used for path verification.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited