FidoMetadataAuthenticatorStatus enum

The status values currently defined by FIDO Metadata Service 3.1.1.

Inheritance
Available extensions

Values

notFidoCertified → const FidoMetadataAuthenticatorStatus

The authenticator has not completed FIDO certification.

fidoCertified → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO certified.

userVerificationBypass → const FidoMetadataAuthenticatorStatus

The authenticator permits bypassing user verification.

attestationKeyCompromise → const FidoMetadataAuthenticatorStatus

The authenticator's attestation key has been compromised.

userKeyRemoteCompromise → const FidoMetadataAuthenticatorStatus

The authenticator's user key has been compromised remotely.

userKeyPhysicalCompromise → const FidoMetadataAuthenticatorStatus

The authenticator's user key has been compromised physically.

updateAvailable → const FidoMetadataAuthenticatorStatus

An update is available for the authenticator.

retired → const FidoMetadataAuthenticatorStatus

The authenticator has been retired.

revoked → const FidoMetadataAuthenticatorStatus

The authenticator has been revoked.

selfAssertionSubmitted → const FidoMetadataAuthenticatorStatus

The authenticator's self-asserted status was submitted.

fidoCertifiedL1 → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 1.

fidoCertifiedL1Plus → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 1 Plus.

fidoCertifiedL2 → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 2.

fidoCertifiedL2Plus → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 2 Plus.

fidoCertifiedL3 → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 3.

fidoCertifiedL3Plus → const FidoMetadataAuthenticatorStatus

The authenticator is FIDO Certified Level 3 Plus.

fips140CertifiedL1 → const FidoMetadataAuthenticatorStatus

The authenticator is FIPS 140 certified at Level 1.

fips140CertifiedL2 → const FidoMetadataAuthenticatorStatus

The authenticator is FIPS 140 certified at Level 2.

fips140CertifiedL3 → const FidoMetadataAuthenticatorStatus

The authenticator is FIPS 140 certified at Level 3.

fips140CertifiedL4 → const FidoMetadataAuthenticatorStatus

The authenticator is FIPS 140 certified at Level 4.

unknown → const FidoMetadataAuthenticatorStatus

The status token was not recognized by this version of the package.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FidoMetadataAuthenticatorStatus>
A constant List of the values in this enum, in order of their declaration.