FidoMetadataEvaluationReason enum

The reason attached to a typed metadata evaluation.

Inheritance
Available extensions

Values

accepted → const FidoMetadataEvaluationReason

The metadata entry and status allowed the attestation.

downgraded → const FidoMetadataEvaluationReason

The metadata entry allowed the attestation with reduced trust.

noMatchingEntry → const FidoMetadataEvaluationReason

No metadata entry matched the attestation.

certificatePathUntrusted → const FidoMetadataEvaluationReason

The attestation certificate path could not be trusted to a metadata root.

statusRejected → const FidoMetadataEvaluationReason

The metadata status rejected the authenticator.

statusUnavailable → const FidoMetadataEvaluationReason

The metadata status was unknown or unavailable.

updateVersionMismatch → const FidoMetadataEvaluationReason

The authenticator version did not satisfy an update requirement.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FidoMetadataEvaluationReason>
A constant List of the values in this enum, in order of their declaration.