FidoMetadataHttpRequest class final

A bounded, single-hop HTTP GET request used by the MDS downloader.

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Request headers sent by the transport.
final
maxResponseBytes int
Maximum response body size accepted by the request.
final
maxResponseHeaderBytes int
Maximum response-header size accepted by the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Absolute timeout for this request.
final
uri Uri
HTTPS URI requested by the downloader.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited