FidoMetadataRefreshResult class final

Result of a remote metadata refresh.

Properties

blob FidoMetadataBlob
Authenticated metadata blob available after the refresh.
final
etag String?
ETag returned by the source, when available.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wasDownloaded bool
Whether the refresh downloaded and verified a new blob.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited