GitLabProfile class

GitLab user profile.

See GitLab User API.

Constructors

GitLabProfile({required int id, required String username, String? email, String? name, String? avatarUrl, String? webUrl, String? state, String? bio, String? location, String? publicEmail, String? websiteUrl, String? organization, String? jobTitle, bool? twoFactorEnabled, bool? isAdmin, String? createdAt})
Creates a new GitLabProfile with the given fields.
const
GitLabProfile.fromJson(Map<String, dynamic> json)
Creates a GitLabProfile from a JSON map returned by the GitLab API.
factory

Properties

avatarUrl String?
URL of the user's avatar.
final
bio String?
User's bio.
final
createdAt String?
When the account was created.
final
email String?
User's primary email.
final
hashCode int
The hash code for this object.
no setterinherited
id int
User ID.
final
isAdmin bool?
Whether user is admin.
final
jobTitle String?
User's job title.
final
location String?
User's location.
final
name String?
User's display name.
final
organization String?
User's organization.
final
publicEmail String?
User's public email.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Account state (active, blocked, etc.).
final
twoFactorEnabled bool?
Whether 2FA is enabled.
final
username String
User's username.
final
websiteUrl String?
User's website URL.
final
webUrl String?
URL to user's GitLab profile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this profile to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited