JwtIssuer class

A JWT issuer that produces signed tokens for auth sessions.

Constructors

JwtIssuer(JwtSessionOptions options)
Creates a JwtIssuer with the given session options.

Properties

expiry DateTime
The expiry time for a token issued right now.
no setter
hashCode int
The hash code for this object.
no setterinherited
options JwtSessionOptions
The session configuration used for signing tokens.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

issue(Map<String, dynamic> claims) String
Issues a signed JWT containing the given claims.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited