OAuthAuthorizationCodePreparation class final

Result of preparing an authorization-code exchange.

Constructors

OAuthAuthorizationCodePreparation.invalidGrant()
Creates a failed result without revealing persisted authorization data.
const
OAuthAuthorizationCodePreparation.ready(OAuthAuthorizationCode authorization)
Creates a successful result containing the persisted authorization.
const

Properties

authorization OAuthAuthorizationCode?
Persisted authorization when preparation succeeded.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status OAuthAuthorizationCodePreparationStatus
Outcome of preparation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited