Policy<T extends Object> class abstract

Resource policy contract.

Constructors

Policy()
Creates a policy contract for resources of type T.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canCreate(AuthPrincipal? principal) FutureOr<bool>
Whether the principal can create a resource.
canDelete(AuthPrincipal? principal, T resource) FutureOr<bool>
Whether the principal can delete a resource.
canUpdate(AuthPrincipal? principal, T resource) FutureOr<bool>
Whether the principal can update a resource.
canView(AuthPrincipal? principal, T resource) FutureOr<bool>
Whether the principal can view a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited