SessionRememberMeConfig class

Remember-me cookie settings for session authentication.

Constructors

SessionRememberMeConfig({required String? cookieName, required Duration duration})
Creates remember-me settings.
const

Properties

cookieName String?
Name of the remember-me cookie, or null to disable it.
final
duration Duration
Lifetime assigned to remember-me credentials.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited