SpotifyProfile class

Spotify user profile.

See Spotify Web API User Object.

Constructors

SpotifyProfile({required String id, String? displayName, String? email, List<SpotifyImage>? images, String? country, String? href, String? uri, String? product, Map<String, dynamic>? explicitContent, SpotifyFollowers? followers})
Creates a new SpotifyProfile with the given fields.
const
SpotifyProfile.fromJson(Map<String, dynamic> json)
Creates a SpotifyProfile from a JSON map returned by the Spotify Web API.
factory

Properties

country String?
User's country code.
final
displayName String?
User's display name.
final
email String?
User's email address.
final
explicitContent Map<String, dynamic>?
Explicit content settings.
final
followers SpotifyFollowers?
Follower information.
final
hashCode int
The hash code for this object.
no setterinherited
href String?
Link to the user's profile.
final
id String
User's Spotify user ID.
final
images List<SpotifyImage>?
User's profile images.
final
imageUrl String?
Returns the URL of the first profile image.
no setter
product String?
User's subscription level (premium, free, etc.).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
Spotify URI for the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this profile to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited