WebAuthnUserInfo class

User info returned by WebAuthn getUserInfo callback.

Constructors

WebAuthnUserInfo({required AuthUser user, required bool exists})
Creates the user information returned by a WebAuthn callback.
const

Properties

exists bool
Whether the user already exists in the database.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
The user (new or existing).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited