AuthPluginRuntimePhoneDelivery class final

A copy of one provider-owned phone-code delivery.

Constructors

AuthPluginRuntimePhoneDelivery({required String phoneNumber, required String code, required DateTime expiresAt})
Creates a captured phone-code delivery.
const

Properties

code String
One-time code delivered to phoneNumber.
final
expiresAt DateTime
Time at which code expires.
final
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String
Phone number to which the code was sent.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited