AuthRuntimeConformanceFailure class final

A failed auth runtime conformance assertion.

Implemented types

Constructors

AuthRuntimeConformanceFailure({required String caseId, required String message})
Creates a failure for a stable caseId.
const

Properties

caseId String
Stable machine-readable identifier for the failed behavior.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable failure detail.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a stable description containing the failed case identifier.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited