AuthRuntimeConformanceResponse class final

A framework-neutral response returned by a host transport adapter.

Constructors

AuthRuntimeConformanceResponse({required int statusCode, required Map<String, List<String>> headers, required String body})
Creates a captured response.
const

Properties

body String
UTF-8 response body.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
Response headers, preserving repeated values.
final
json Object?
Decodes body as JSON, or returns null for an empty body.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP response status.
final

Methods

headerValues(String name) List<String>
Returns all values for name using case-insensitive matching.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited