AdminPlugin<TContext> class
final
Server plugin that exposes administrative user and session operations.
- Implemented types
Constructors
-
AdminPlugin({required AuthAdminStore store, AuthAdminOptions<
TContext> ? options}) - Creates an instance of AdminPlugin.
Properties
- accessControl → AuthAdminAccessControl
-
The access control associated with this value.
final
-
clientOperations
→ Iterable<
AuthClientOperationDescriptor> -
The client operations exposed by this plugin.
no setteroverride
- dataContract → AuthServerPluginDataContract
-
The persistence and data contract exposed by this plugin.
no setteroverride
-
endpoints
→ Iterable<
AuthEndpointDescriptor< TContext> > -
The endpoint descriptors exposed by this plugin.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The identifier exposed by this component.
no setteroverride
-
options
→ AuthAdminOptions<
TContext> -
The options associated with this value.
final
-
persistenceSchemas
→ Iterable<
AuthPersistenceSchema> -
The persistence schemas exposed by this plugin.
no setteroverride
-
rateLimitOperations
→ Iterable<
AuthRateLimitOperation> -
The rate-limit operations exposed by this plugin.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → AuthAdminStore
-
The persistence store used by this component.
final
- userDataNamespace → String
-
The namespace used for plugin-owned user data.
no setteroverride
Methods
-
composePluginTopology(
Iterable< AuthServerPlugin< plugins) → voidTContext> > -
Performs the compose plugin topology operation.
override
-
configure(
AuthServerPluginContext< TContext> context) → void -
Configures the requested value.
override
-
createUserDeletionPlan(
AuthUser user) → Future< AuthUserDeletionPlan> -
Creates user deletion plan.
override
-
enforceAuthenticationPolicy(
AuthAuthenticationPolicyRequest< TContext> request) → Future<void> -
Performs the enforce authentication policy operation.
override
-
hasPermission(
String actorId, String resource, String action) → Future< bool> - Returns whether this value has permission.
-
isAdministrator(
AuthUser user) → bool - Returns whether this value is administrator.
-
localRoleAllows(
Iterable< String> roles, String resource, String action) → bool - Performs the local role allows operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trustedGrantAdministrator(
String userId) → Future< AuthAdminUser> - Trusted Dart-only bootstrap operation; never contributed as a route.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited