AuthAccountDeletionDelivery<TContext> class
final
Application delivery payload for account-deletion confirmation.
Constructors
- AuthAccountDeletionDelivery({required TContext context, required AuthUser user, required String token, required DateTime expiresAt})
-
Creates an instance of AuthAccountDeletionDelivery.
const
Properties
- context → TContext
-
The host context associated with this operation.
final
- expiresAt → DateTime
-
The time at which expires occurred.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
The token used for token.
final
- user → AuthUser
-
The user associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited