AuthAccountLinked class
Result of linking a provider account.
Constructors
- AuthAccountLinked({required String providerId, required String providerAccountId, required DateTime linkedAt, required bool isNewLink})
-
Creates an instance of AuthAccountLinked.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNewLink → bool
-
Whether this was a new link (not already linked).
final
- linkedAt → DateTime
-
When the account was linked.
final
- providerAccountId → String
-
Provider-specific account ID.
final
- providerId → String
-
Provider identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this value to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited