AuthAdminClientPlugin class final
Installs the typed administrative API on an AuthClient.
- Implemented types
Constructors
-
AuthAdminClientPlugin({Map<
String, AuthAdminPermissionSet> ? roles}) -
Creates an instance of AuthAdminClientPlugin.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The identifier exposed by this component.
no setteroverride
-
roles
→ Map<
String, AuthAdminPermissionSet> ? -
The roles assigned to this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
install(
AuthClientPluginContext context) → AuthAdminClient -
Installs the requested value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited