AuthAdminCreateUserMutation class final
Mutation describing auth admin create user mutation.
- Inheritance
-
- Object
- AuthAdminMutation<
AuthAdminUser> - AuthAdminCreateUserMutation
Constructors
- AuthAdminCreateUserMutation({required AuthAdminMutationAuthorization? authorization, required AuthUser user, required AuthPasswordCredential credential})
-
Creates an instance of AuthAdminCreateUserMutation.
const
Properties
-
The authorization associated with this value.
finalinherited
- credential → AuthPasswordCredential
-
The credential associated with this mutation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → AuthUser
-
The user associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited