AuthAdminTrustedReplaceRolesMutation class final
Trusted bootstrap-only role grant. This command is never route-contributed.
- Inheritance
-
- Object
- AuthAdminMutation<
AuthAdminUser> - AuthAdminTrustedReplaceRolesMutation
Constructors
Properties
-
administratorRoles
→ Set<
String> -
The roles assigned to this value.
final
-
administratorUserIds
→ Set<
String> -
The administrator user ids associated with this value.
final
-
The authorization associated with this value.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
roles
→ List<
String> -
The roles assigned to this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
The identifier of the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited