AuthAdminUserPage class final
A page of auth admin user page.
Constructors
-
AuthAdminUserPage({required List<
AuthAdminUser> items, required int total, required int limit, required int offset}) -
Creates an instance of AuthAdminUserPage.
const
-
AuthAdminUserPage.fromJson(Map<
String, dynamic> json) -
Creates an instance from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
AuthAdminUser> -
The items associated with this value.
final
- limit → int
-
The limit associated with this value.
final
- offset → int
-
The offset associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
The total associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this value to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited