AuthAnonymousMutationResult class final
Result returned by an anonymous-account mutation backend.
Constructors
- AuthAnonymousMutationResult(AuthAnonymousMutationStatus status, {AuthUser? user})
-
Creates an instance of AuthAnonymousMutationResult.
const
Properties
- committed → bool
-
The committed exposed by this component.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthAnonymousMutationStatus
-
The status associated with this value.
final
- user → AuthUser?
-
The user associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited