AuthAuthenticationPolicyRequest<TContext> class
final
Context supplied to an authentication policy contributor.
Constructors
- AuthAuthenticationPolicyRequest({required TContext context, required AuthUser user, required AuthAuthenticationPolicyPhase phase})
-
Creates a request for an authentication policy contributor.
const
Properties
- context → TContext
-
Framework context associated with the authentication attempt.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phase → AuthAuthenticationPolicyPhase
-
Policy phase being evaluated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → AuthUser
-
User being authenticated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited