AuthClientApiKey class final
Public API-key metadata returned by the auth API.
Constructors
-
AuthClientApiKey({required String id, required String userId, required String name, required String keyPrefix, required List<
String> scopes, required DateTime createdAt, required DateTime updatedAt, required bool active, DateTime? expiresAt, DateTime? lastUsedAt, DateTime? revokedAt}) -
Creates public API-key metadata.
const
-
AuthClientApiKey.fromJson(Map<
String, dynamic> json) -
Decodes API-key metadata from a JSON object.
factory
Properties
- active → bool
-
Whether the key can currently authenticate.
final
- createdAt → DateTime
-
Time at which the key was created.
final
- expiresAt → DateTime?
-
Time at which the key expires, if configured.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Public API-key identifier.
final
- keyPrefix → String
-
Non-secret prefix used to identify the key in logs and interfaces.
final
- lastUsedAt → DateTime?
-
Time at which the key was last used, if it has been used.
final
- name → String
-
Human-readable key name.
final
- revokedAt → DateTime?
-
Time at which the key was revoked, if it was revoked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
Permissions granted to the key.
final
- updatedAt → DateTime
-
Time at which the key metadata was last changed.
final
- userId → String
-
Identifier of the user who owns the key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited