AuthClientIssuedApiKey class final
The one-time API-key response returned after create or rotate.
Constructors
- AuthClientIssuedApiKey({required AuthClientApiKey apiKey, required String key})
-
Creates the one-time raw-key response.
const
-
AuthClientIssuedApiKey.fromJson(Map<
String, dynamic> json) -
Decodes a one-time API-key response from JSON.
factory
Properties
- apiKey → AuthClientApiKey
-
Public metadata for the issued key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Raw secret key, returned only during issuance or rotation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited