AuthClientOperationDescriptor class final
Describes one client-visible operation exposed by an auth plugin.
Constructors
- AuthClientOperationDescriptor({required String id, required AuthOperationMethod method, required AuthRoutePath path, bool serverOnly = false, AuthEndpointMount mount = AuthEndpointMount.auth})
-
Creates a client operation descriptor.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable operation identifier.
final
- method → AuthOperationMethod
-
HTTP method used by the operation.
final
- mount → AuthEndpointMount
-
Mount location selected by the operation.
final
- path → AuthRoutePath
-
Canonical route path used by the operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverOnly → bool
-
Whether the operation is intended only for server-side callers.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited