AuthDeviceAuthorizationClient class final
Client for starting, polling, approving, and denying device authorization.
Constructors
- AuthDeviceAuthorizationClient(AuthClientCore _core)
- Creates a device-authorization client backed by the shared client transport.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
approve(
{required String userCode}) → Future< void> -
Approves a pending device authorization using
userCode. -
Requests a device code for
clientIdandscopes. -
deny(
{required String userCode}) → Future< void> -
Denies a pending device authorization using
userCode. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
poll(
{required String clientId, required String deviceCode}) → Future< AuthClientDeviceAccessToken> -
Polls the token endpoint once for
deviceCode. -
pollUntilComplete(
{required String clientId, required AuthClientDeviceAuthorization authorization, AuthDeviceAuthorizationPollingOptions? options}) → Future< AuthClientDeviceAccessToken> - Polls until the device authorization succeeds or reaches a terminal server or local state.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited