AuthDeviceAuthorizationIssuanceLeaseResult class final
Result of attempting to acquire an issuance lease.
Constructors
- AuthDeviceAuthorizationIssuanceLeaseResult(AuthDeviceAuthorizationIssuanceLeaseStatus status, [AuthDeviceAuthorizationIssuanceLease? lease])
-
Creates a result with
statusand an optional acquiredlease.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lease → AuthDeviceAuthorizationIssuanceLease?
-
Acquired lease, or null for busy and invalid results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthDeviceAuthorizationIssuanceLeaseStatus
-
Whether the lease was acquired, busy, or invalid.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited