AuthDeviceAuthorizationPollResult class final
Result of atomically polling a device authorization request.
Constructors
- AuthDeviceAuthorizationPollResult(AuthDeviceAuthorizationPollStatus status, [AuthDeviceAuthorization? authorization])
-
Creates a poll result with
statusand optionalauthorization.const
Properties
-
Matching record, when one exists; null for an invalid lookup.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthDeviceAuthorizationPollStatus
-
Store outcome mapped by the plugin to an RFC 8628 response.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited