AuthDeviceAuthorizationRequest class final
Raw values returned once when a device starts authorization.
Constructors
Properties
- deviceCode → String
-
Raw device code presented when polling for a token.
final
- expiresIn → Duration
-
Time until the device code expires.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Duration
-
Minimum polling interval recommended to the device client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userCode → String
-
Human-entered code used by the verification UI.
final
- verificationUri → String
-
URI where the user enters userCode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this response with RFC 8628 field names and second values.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited