AuthEmailChangeConfirmed class final
Result returned after a pending email change is confirmed.
Constructors
- AuthEmailChangeConfirmed({required String userId, required String oldEmail, required String newEmail, required int sessionsRevoked})
-
Creates the result of confirming an email change.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newEmail → String
-
Canonical email address after confirmation.
final
- oldEmail → String
-
Email address before confirmation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionsRevoked → int
-
Number of existing sessions revoked by the compatibility flow.
final
- userId → String
-
User whose email was changed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited