AuthEmailOtpIssueCommand class final
Persists a digest-only email OTP, replacing the active purpose-specific record for its canonical email.
Constructors
- AuthEmailOtpIssueCommand(AuthEmailOtp otp)
- Creates a command for replacing a fresh digest-only OTP record.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- otp → AuthEmailOtp
-
Validated OTP record to persist atomically.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited