AuthEmailOtpSignInCommand class final
Atomically consumes a sign-in OTP and resolves its verified local user.
Constructors
Properties
- candidate → AuthUser
-
Stable candidate data for a possible user creation.
final
- codeHash → String
-
Application-keyed digest of the submitted code.
final
- disableSignUp → bool
-
Whether unknown email addresses must be rejected.
final
- email → String
-
Canonical email bound to the OTP.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- now → DateTime
-
UTC time used for expiry and attempt accounting.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited