AuthEmailUserResolution class
Result of resolving an email sign-in user.
Constructors
- AuthEmailUserResolution({required AuthUser user, required bool isNewUser})
-
Creates the result of resolving an email address to a user.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited