Describes and invokes one framework-neutral auth endpoint.
Properties
- authentication → AuthOperationAuthentication
-
Authentication boundary required by the endpoint.
no setter
- csrfPolicy → AuthOperationCsrfPolicy
-
CSRF policy required by the endpoint.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable endpoint identifier.
no setter
- method → AuthOperationMethod
-
HTTP method used by the endpoint.
no setter
- mount → AuthEndpointMount
-
Mount location selected by the endpoint.
no setter
- originPolicy → AuthOperationOriginPolicy
-
Browser-origin policy required by the endpoint.
no setter
- path → AuthRoutePath
-
Canonical route path used by the endpoint.
no setter
- rateLimitOperation → AuthRateLimitOperation?
-
Rate-limit operation applied by the host, when configured.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semantics → AuthOperationSemantics
-
Persistence and replay semantics declared by the endpoint.
no setter
- serverOnly → bool
-
Whether the endpoint is available only to server-side callers.
no setter
Methods
-
invoke(
AuthOperationInvocation< TContext> invocation, AuthEndpointRequest request) → FutureOr<Object?> -
Invokes the endpoint with
invocationandrequest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited