AuthInMemoryCompositeDeletionOperation class final
Composes multiple typed in-memory operations owned by one plugin.
- Implemented types
Constructors
-
AuthInMemoryCompositeDeletionOperation(Iterable<
AuthInMemoryUserDeletionOperation> operations) - Creates an instance of AuthInMemoryCompositeDeletionOperation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
) → Future< void> -
Applies the requested value.
override
-
captureState(
) → List< Object> -
Captures state.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreState(
Object state) → Future< void> -
Restores state.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited