AuthOAuthClientRegistration class final
The application-owned result of registering an OAuth client.
Constructors
-
AuthOAuthClientRegistration({required String clientId, required List<
Uri> redirectUris, required List<String> grantTypes, required List<String> responseTypes, required String tokenEndpointAuthMethod, String? clientSecret, String? clientName}) -
Creates a client-registration result returned by the application.
const
Properties
- clientId → String
-
Identifier assigned to the registered client.
final
- clientName → String?
-
Display name recorded for the client, when available.
final
- clientSecret → String?
-
Secret assigned to the client, when the registration requires one.
final
-
grantTypes
→ List<
String> -
OAuth grant types enabled for the client.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
redirectUris
→ List<
Uri> -
Redirect URIs authorized for the client.
final
-
responseTypes
→ List<
String> -
OAuth response types enabled for the client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenEndpointAuthMethod → String
-
Token-endpoint authentication method enabled for the client.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this registration using OAuth client metadata field names.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited