AuthOrganizationCreateStoredResult class final
Result returned by auth organization create stored result.
Constructors
- AuthOrganizationCreateStoredResult({required AuthOrganization organization, required AuthOrganizationMember creatorMembership, AuthOrganizationTeam? defaultTeam, bool replayed = false})
-
Creates an instance of AuthOrganizationCreateStoredResult.
const
Properties
- creatorMembership → AuthOrganizationMember
-
The creator membership associated with this value.
final
- defaultTeam → AuthOrganizationTeam?
-
The default team associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organization → AuthOrganization
-
The organization associated with this value.
final
- replayed → bool
-
The replayed associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited