AuthOrganizationOptions<TContext> class
final
Configuration for organization, membership, invitation, and team operations.
Constructors
-
AuthOrganizationOptions({bool allowUserToCreateOrganization = true, AuthOrganizationCreationPolicy? creationPolicy, int? organizationLimit, String creatorRole = 'owner', int? membershipLimit = 100, int? invitationLimit = 100, Duration invitationExpiresIn = const Duration(hours: 48), bool replacePendingInvitations = false, bool requireVerifiedEmailForInvitations = false, AuthOrganizationInvitationIdGenerator? invitationIdGenerator, bool invitationIdGeneratorIsOpaque = false, bool disableOrganizationDeletion = false, bool dynamicRoles = false, int? dynamicRoleLimit, Map<
String, AuthOrganizationPermissionSet> ? staticRoles, AuthOrganizationTeamsOptions teams = const AuthOrganizationTeamsOptions(), AuthOrganizationHooks<TContext> hooks = const AuthOrganizationHooks(), AuthOrganizationInvitationSender<TContext> ? sendInvitation, AuthOrganizationFailureReporter? reportFailure, AuthOrganizationEventSink? emitEvent}) -
Creates an instance of AuthOrganizationOptions.
const
Properties
- allowUserToCreateOrganization → bool
-
The allow user to create organization associated with this value.
final
- creationPolicy → AuthOrganizationCreationPolicy?
-
The creation policy associated with this value.
final
- creatorRole → String
-
The roles assigned to this value.
final
- disableOrganizationDeletion → bool
-
The disable organization deletion associated with this value.
final
- dynamicRoleLimit → int?
-
The roles assigned to this value.
final
- dynamicRoles → bool
-
The roles assigned to this value.
final
- emitEvent → AuthOrganizationEventSink?
-
The emit event associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hooks
→ AuthOrganizationHooks<
TContext> -
Lifecycle hooks invoked by this component.
final
- invitationExpiresIn → Duration
-
The invitation expires in associated with this value.
final
- invitationIdGenerator → AuthOrganizationInvitationIdGenerator?
-
The invitation id generator associated with this value.
final
- invitationIdGeneratorIsOpaque → bool
-
The invitation id generator is opaque associated with this value.
final
- invitationLimit → int?
-
The invitation limit associated with this value.
final
- membershipLimit → int?
-
The membership limit associated with this value.
final
- organizationLimit → int?
-
The organization limit associated with this value.
final
- replacePendingInvitations → bool
-
The replace pending invitations associated with this value.
final
- reportFailure → AuthOrganizationFailureReporter?
-
The report failure associated with this value.
final
- requireVerifiedEmailForInvitations → bool
-
The require verified email for invitations associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sendInvitation
→ AuthOrganizationInvitationSender<
TContext> ? -
The send invitation associated with this value.
final
-
staticRoles
→ Map<
String, AuthOrganizationPermissionSet> ? -
The roles assigned to this value.
final
- teams → AuthOrganizationTeamsOptions
-
The teams associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited