AuthOrganizationTeamsOptions class final
Configuration for organization team behavior.
Constructors
Properties
- allowRemovingLastTeam → bool
-
The allow removing last team associated with this value.
final
- createDefaultTeam → bool
-
The create default team associated with this value.
final
- defaultTeamName → String
-
The default team name associated with this value.
final
- enabled → bool
-
The enabled associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamLimit → int?
-
The team limit associated with this value.
final
- teamMemberLimit → int?
-
The team member limit associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited