AuthPhoneNumberIssueResult class final
Store result returned by an atomic phone-code issue command.
Constructors
- AuthPhoneNumberIssueResult(AuthPhoneNumberIssueStatus status, {AuthPhoneNumberVerification? verification})
-
Creates the outcome of an issue command.
const
Properties
- committed → bool
-
Whether the operation created or replayed a committed challenge.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthPhoneNumberIssueStatus
-
Outcome of the issue operation.
final
- verification → AuthPhoneNumberVerification?
-
Challenge committed by the store, when available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited