Optional exact transaction for removing a verified phone identity safely.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removePhoneNumberIfSafe(
AuthPhoneNumberRemovalCommand command) → FutureOr< AuthAuthenticationMethodMutationResult> - Removes the identity when the composed auth topology remains usable.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited