AuthSamlNameIdFormat enum
NameID formats accepted by the SAML connection policy.
Values
- persistent → const AuthSamlNameIdFormat
-
A persistent identifier assigned by the identity provider.
const AuthSamlNameIdFormat('urn:oasis:names:tc:SAML:2.0:nameid-format:persistent') - emailAddress → const AuthSamlNameIdFormat
-
An identifier containing an email address.
const AuthSamlNameIdFormat('urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress') - unspecified → const AuthSamlNameIdFormat
-
An identifier whose format is not otherwise specified.
const AuthSamlNameIdFormat('urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
The SAML URI identifying this format.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthSamlNameIdFormat> - A constant List of the values in this enum, in order of their declaration.