AuthSamlXmlDsigDigestAlgorithm enum
Digest methods implemented by AuthPortableSamlXmlDsigVerifier.
Values
- sha256 → const AuthSamlXmlDsigDigestAlgorithm
-
SHA-256 with a 32-byte digest.
const AuthSamlXmlDsigDigestAlgorithm('http://www.w3.org/2001/04/xmlenc#sha256', 32) - sha384 → const AuthSamlXmlDsigDigestAlgorithm
-
SHA-384 with a 48-byte digest.
const AuthSamlXmlDsigDigestAlgorithm('http://www.w3.org/2001/04/xmldsig-more#sha384', 48) - sha512 → const AuthSamlXmlDsigDigestAlgorithm
-
SHA-512 with a 64-byte digest.
const AuthSamlXmlDsigDigestAlgorithm('http://www.w3.org/2001/04/xmlenc#sha512', 64)
Properties
- byteLength → int
-
The digest length in bytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
The XMLDSig digest-method URI.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthSamlXmlDsigDigestAlgorithm> - A constant List of the values in this enum, in order of their declaration.