AuthScimApplicationProjectionDriftPage class final
A page of drift findings for one projection scope.
Constructors
-
AuthScimApplicationProjectionDriftPage({required AuthScimApplicationProjectionScope scope, required Iterable<
AuthScimApplicationProjectionDrift> findings, required int total, required String projectionSnapshotId}) - Creates a validated drift page.
Properties
-
findings
→ List<
AuthScimApplicationProjectionDrift> -
Drift findings returned for the requested range.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectionSnapshotId → String
-
Digest identifying the projection snapshot used for the page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → AuthScimApplicationProjectionScope
-
Scope shared by every finding in the page.
final
- total → int
-
Total findings available in the scope.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited