AuthScimApplicationProjectionDriftQuery class final
Snapshot-bound, bounded drift query.
Constructors
-
AuthScimApplicationProjectionDriftQuery({required AuthScimApplicationProjectionScope scope, required String sourceSnapshotId, required Iterable<
AuthScimApplicationProjectionSnapshot> authoritative, int offset = 0, int limit = 100}) - Creates a query against a complete authoritative source snapshot.
Properties
-
Complete authoritative snapshots for scope.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
Maximum number of findings to return.
final
- offset → int
-
Zero-based finding offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → AuthScimApplicationProjectionScope
-
Exact scope to inspect.
final
- sourceSnapshotId → String
-
Digest of authoritative.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited