AuthScimGroup class final
Connection-bound SCIM Group resource returned by an application store.
Constructors
- AuthScimGroup({required String connectionId, required String tenantId, required String organizationId, required String provisioningDomainId, required String id, required AuthScimGroupData data, required AuthScimResourceMeta meta, required AuthScimDirectoryGroupState state, DateTime? tombstonedAt})
- Creates a connection-bound SCIM Group resource.
Properties
- connectionId → String
-
Immutable connection that owns this directory resource.
final
- data → AuthScimGroupData
-
Provisioned Group attributes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
SCIM resource identifier.
final
- meta → AuthScimResourceMeta
-
Resource metadata returned to the client.
final
- organizationId → String
-
Internal organization boundary omitted from SCIM JSON.
final
- provisioningDomainId → String
-
Application provisioning boundary.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AuthScimDirectoryGroupState
-
Internal lifecycle state.
final
- tenantId → String
-
Internal tenant boundary omitted from SCIM JSON.
final
- tombstonedAt → DateTime?
-
Tombstone timestamp, when state is tombstoned.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this Group resource without internal tenancy fields.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited