AuthScimGroupFilter class final
A bounded equality filter for Group listing.
Constructors
- AuthScimGroupFilter({required AuthScimGroupFilterAttribute attribute, required String value})
-
Creates an equality filter for
attributeandvalue.const - AuthScimGroupFilter.parse(String source)
-
Parses the bounded SCIM Group equality filter syntax.
factory
Properties
- attribute → AuthScimGroupFilterAttribute
-
Attribute tested by this filter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Exact value to compare.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited