AuthScimGroupPage class final
A page of SCIM Group resources returned by a connection-bound query.
Constructors
-
AuthScimGroupPage({required Iterable<
AuthScimGroup> resources, required int totalResults}) - Creates a page of connection-bound Group resources.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
→ List<
AuthScimGroup> -
Resources in this page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalResults → int
-
Total matching resources before pagination.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited