AuthScimIssueCredentialTransaction class final
Atomic credential issuance command.
Constructors
- AuthScimIssueCredentialTransaction({required AuthScimConnectionBinding binding, required AuthScimCredentialRecord credential, required AuthScimIdempotencyBinding idempotency})
-
Creates an atomic credential-issuance command.
const
Properties
- binding → AuthScimConnectionBinding
-
Tenant and organization binding that owns the credential.
final
- credential → AuthScimCredentialRecord
-
Credential record to persist.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotency → AuthScimIdempotencyBinding
-
Replay binding for this issuance request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited