AuthScimPatchDocument class final
Strict, bounded SCIM PatchOp document.
Constructors
-
AuthScimPatchDocument({required Iterable<
AuthScimPatchOperation> operations}) - Creates a bounded User patch document.
-
AuthScimPatchDocument.fromJson(Map<
String, dynamic> json, {int maximumOperations = 32}) -
Decodes and validates a User PatchOp document.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operations
→ List<
AuthScimPatchOperation> -
Operations applied in request order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
AuthScimUserData current) → AuthScimUserData - Applies this validated document to current user data.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited