AuthScimServiceProviderConfig class final
Typed ServiceProviderConfig response.
Constructors
- AuthScimServiceProviderConfig({required int maximumPageSize, required int maximumPatchOperations})
-
Creates a typed service-provider configuration response.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumPageSize → int
-
Maximum page size accepted by the provider.
final
- maximumPatchOperations → int
-
Maximum PatchOp operations accepted by the provider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes the SCIM service-provider configuration response.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited