AuthSignInRouteDecision class
Concrete sign-in routing decision used by framework adapters.
Constructors
- AuthSignInRouteDecision.credentials()
-
Creates a credentials decision that requires CSRF handling.
const
- AuthSignInRouteDecision.email(String email)
-
Creates a magic-link decision for
emailthat requires CSRF handling.const - AuthSignInRouteDecision.error(String errorCode, {bool requiresCsrf = false})
-
Creates an error decision carrying
errorCode.const - AuthSignInRouteDecision.oauth()
-
Creates an OAuth decision that does not require adapter CSRF handling.
const
Properties
- email → String?
-
Email selected for AuthSignInRouteKind.email.
final
- errorCode → String?
-
Stable error code, present for AuthSignInRouteKind.error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → AuthSignInRouteKind
-
Selected sign-in branch.
final
- requiresCsrf → bool
-
Whether the adapter should perform CSRF handling for this branch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited