AuthTwoFactorStepUpRecord class
Persisted state for a recent step-up proof.
Constructors
Properties
- createdAt → DateTime
-
Time at which the proof was issued.
final
- expiresAt → DateTime
-
Time at which the proof expires.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable identifier for this proof record.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionBindingHash → String
-
Digest binding the proof to one authenticated session.
final
- tokenHash → String
-
Digest of the opaque proof token.
final
- userId → String
-
User who completed step-up verification.
final
Methods
-
isActive(
{DateTime? now}) → bool - Returns whether the proof has not expired.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited