AuthTwoFactorUseRecoveryCodeCommand class
Atomically consumes a recovery code or records the failed attempt.
Constructors
- AuthTwoFactorUseRecoveryCodeCommand({required String userId, required String recoveryCodeHash, required AuthTwoFactorAttemptPolicy policy})
-
Creates the command for consuming one recovery-code digest.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → AuthTwoFactorAttemptPolicy
-
Attempt and lockout policy for this command.
final
- recoveryCodeHash → String
-
Digest of the recovery code supplied by the client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
User whose recovery code is being consumed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited