AuthUsernameRegistrationCommand class final
Complete input to an atomic username registration.
Constructors
- AuthUsernameRegistrationCommand({required AuthUser user, required AuthPasswordCredential credential})
- Creates a validated atomic username-registration command.
Properties
- credential → AuthPasswordCredential
-
Canonical username credential owned by user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → AuthUser
-
User projection to create alongside the credential.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited