AuthWebAuthnAuthenticationOptions class final
Public authentication options returned to a WebAuthn client.
Constructors
Properties
-
allowCredentials
→ List<
String> -
Credential IDs allowed for a user-bound ceremony.
final
- challenge → String
-
Base64url challenge that the authenticator must sign.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- relyingPartyId → String
-
Relying-party identifier used by the browser.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Maximum duration allowed for the ceremony.
final
- userId → String?
-
Asserted user identifier, when the ceremony is user-bound.
final
- userVerification → String
-
User-verification requirement sent to the authenticator.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes these options for the browser WebAuthn API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited