GateDefaults class
Default HTTP response details for a denied gate.
Constructors
- GateDefaults({required int statusCode, String? message})
-
Creates denial defaults with an HTTP
statusCodeand optionalmessage.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Optional public denial message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
Status returned when a gate denies access.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited