GitHubEmail class
GitHub email payload returned by /user/emails.
Constructors
- GitHubEmail({required String email, required bool primary, required bool verified, required String visibility})
- Creates an email record returned by GitHub.
-
GitHubEmail.fromJson(Map<
String, dynamic> json) -
Creates an email record from a GitHub API response.
factory
Properties
- email → String
-
Email address reported by GitHub.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primary → bool
-
Whether GitHub marks this address as the account's primary address.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verified → bool
-
Whether GitHub has verified this address.
final
- visibility → String
-
Visibility setting reported by GitHub.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited