InMemoryAuthAccountStateStore class
In-memory account state store for tests and development.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureDeletionState(
) → Object -
Captures deletion state.
override
-
delete(
String userId) → Future< void> -
Deletes the requested value.
override
-
disable(
String userId, {String? reason, DateTime? now}) → Future< AuthAccountState> -
Disables the account.
override
-
enable(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Enables the account.
override
-
find(
String userId) → Future< AuthAccountState?> -
Looks up the requested value.
override
-
findInactiveAccounts(
{required int inactiveDays, DateTime? now}) → Future< List< AuthAccountState> > -
Looks up inactive accounts.
override
-
markEmailVerified(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Records email verified.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordEmailVerificationSent(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Records email verification sent.
override
-
recordFailedLogin(
String userId, {required AuthAccountPolicy policy, DateTime? now}) → Future< AuthAccountState> -
Records failed login.
override
-
recordLogin(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Records login.
override
-
resetFailedAttempts(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Resets failed attempts.
override
-
restoreDeletionState(
Object state) → void -
Restores deletion state.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unlock(
String userId, {DateTime? now}) → Future< AuthAccountState> -
Unlocks the account.
override
-
upsert(
AuthAccountState state) → Future< AuthAccountState> -
Creates or updates the stored value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited