InMemoryAuthPasswordResetTokenStore constructor
InMemoryAuthPasswordResetTokenStore({
- DateTime clock()?,
Creates an in-memory store using clock for expiry checks.
This implementation keeps one record per exact user ID and stores the digest supplied in each AuthPasswordResetToken.
Implementation
InMemoryAuthPasswordResetTokenStore({DateTime Function()? clock})
: _clock = clock ?? DateTime.now;