InMemoryAuthTwoFactorTrustedDeviceStore class final
In-memory trusted-device store for tests and local examples.
- Implemented types
Constructors
- InMemoryAuthTwoFactorTrustedDeviceStore({DateTime clock()?, int maxEntries = 1024})
- Creates a bounded trusted-device store for tests and local examples.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxEntries → int
-
Maximum number of trusted-device records retained by this local store.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureDeletionState(
) → Object -
Captures deletion state.
override
-
create(
AuthTwoFactorTrustedDeviceRecord record) → AuthTwoFactorTrustedDeviceRecord -
Persists a newly issued trusted-device record.
override
-
deleteUserDataForDeletion(
String userId) → void -
Deletes user data for deletion.
override
-
findActive(
String userId, String tokenHash, {required DateTime now}) → AuthTwoFactorTrustedDeviceRecord? -
Finds and marks a matching, unexpired device as used atomically.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreDeletionState(
Object checkpoint) → void -
Restores deletion state.
override
-
revokeAll(
String userId, {required DateTime now}) → void -
Revokes all trusted devices belonging to
userId.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited