LinkedInProfile class
LinkedIn user profile (OIDC).
Constructors
- LinkedInProfile({required String sub, String? email, bool? emailVerified, String? name, String? picture, String? givenName, String? familyName, String? locale})
-
Creates a new LinkedInProfile with the given fields.
const
-
LinkedInProfile.fromJson(Map<
String, dynamic> json) -
Creates a LinkedInProfile from a JSON map returned by the LinkedIn OIDC userinfo endpoint.
factory
Properties
- email → String?
-
User's email address.
final
- emailVerified → bool?
-
Whether the email has been verified.
final
- familyName → String?
-
User's family name.
final
- givenName → String?
-
User's given name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String?
-
User's locale.
final
- name → String?
-
User's full name.
final
- picture → String?
-
URL of the user's profile picture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sub → String
-
Subject identifier (member ID).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this profile to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited