MicrosoftEntraProfile class
Microsoft Entra ID (Azure AD) user profile.
Constructors
- MicrosoftEntraProfile({required String sub, String? email, String? name, String? preferredUsername, String? picture, String? givenName, String? familyName, String? oid, String? tid})
-
Creates a new MicrosoftEntraProfile with the given fields.
const
-
MicrosoftEntraProfile.fromJson(Map<
String, dynamic> json) -
Creates a MicrosoftEntraProfile from a JSON map returned by Microsoft Graph.
factory
Properties
- email → String?
-
User's email address.
final
- familyName → String?
-
User's family/last name.
final
- givenName → String?
-
User's given/first name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
User's display name.
final
- oid → String?
-
Object ID (unique within tenant).
final
- picture → String?
-
URL of the user's profile picture.
final
- preferredUsername → String?
-
User's preferred username (usually email or UPN).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sub → String
-
Subject identifier (unique user ID).
final
- tid → String?
-
Tenant ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this profile to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited