PolicyBinding<T extends Object> class
Binds a policy to an ability prefix.
Constructors
-
PolicyBinding({required Policy<
T> policy, required String abilityPrefix, Set<PolicyAction> actions = const {PolicyAction.view, PolicyAction.create, PolicyAction.update, PolicyAction.delete}}) -
Binds
policyto abilities beginning withabilityPrefix.const
Properties
- abilityPrefix → String
-
Prefix used to build ability names (e.g.
project).final -
actions
→ Set<
PolicyAction> -
Actions to register for this policy.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
policy
→ Policy<
T> -
Policy instance used for evaluations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited