RoutedAuthLastAuthenticationMethodBrowserStore class final
Routed host adapter for the server plugin's Secure, HttpOnly cookie.
- Implemented types
-
- AuthLastAuthenticationMethodBrowserStore<
EngineContext>
- AuthLastAuthenticationMethodBrowserStore<
Constructors
- RoutedAuthLastAuthenticationMethodBrowserStore()
-
Creates the Routed cookie-store adapter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readCookie(
EngineContext context, String name) → String? -
Reads only the named request cookie value, or null when it is absent.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeCookie(
EngineContext context, AuthLastAuthenticationMethodCookie cookie) → void -
Writes the host-owned cookie instructions to the response.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited