AuthRuntimeConformanceFailure class final
A failed auth runtime conformance assertion.
- Implemented types
Constructors
- AuthRuntimeConformanceFailure({required String caseId, required String message})
-
Creates a failure for a stable
caseId.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a stable description containing the failed case identifier.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited