AuthRuntimeConformanceRequest class final
A framework-neutral HTTP request issued by the auth runtime conformance test.
Constructors
Properties
- body → String?
-
Optional UTF-8 request body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, List< String> > -
Request headers, preserving repeated values.
final
- method → String
-
HTTP method.
final
- path → String
-
Origin-relative request path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited