AuthRuntimeConformanceResponse class final
A framework-neutral response returned by a host transport adapter.
Constructors
Properties
- body → String
-
UTF-8 response body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, List< String> > -
Response headers, preserving repeated values.
final
- json → Object?
-
Decodes body as JSON, or returns
nullfor an empty body.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP response status.
final
Methods
-
headerValues(
String name) → List< String> -
Returns all values for
nameusing case-insensitive matching. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited